@@ -1,7 +1,4 @@
-import DefaultTable
-import Numeric
 from fontTools import ttLib
-from fontTools.misc.textTools import safeEval
 
 superclass = ttLib.getTableClass("hmtx")
 
@@ -11,4 +8,3 @@ class table__v_m_t_x(superclass):
 	advanceName = 'height'
 	sideBearingName = 'tsb'
 	numberOfMetricsName = 'numberOfVMetrics'
-
